Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: chrome/renderer/extensions/custom_bindings_util.h

Issue 9403006: Extensions: run "custom bindings" v8-extensions in content scripts. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/extensions/custom_bindings_util.h
diff --git a/chrome/renderer/extensions/custom_bindings_util.h b/chrome/renderer/extensions/custom_bindings_util.h
index 8b0b4290bf8d97c7671bf0b464b7000f2e707697..15b86ce68b4cab8cc86911b9a254d14417791435 100644
--- a/chrome/renderer/extensions/custom_bindings_util.h
+++ b/chrome/renderer/extensions/custom_bindings_util.h
@@ -33,10 +33,12 @@ std::vector<v8::Extension*> GetAll(ExtensionDispatcher* extension_dispatcher);
std::string GetAPIName(const std::string& v8_extension_name);
// Returns whether the custom binding for an API should be allowed to run for
// |extension|. This is based on whether the extension has any permission
// (required or optional) for that API.
bool AllowAPIInjection(const std::string& api_name,
- const Extension& extension);
+ const Extension& extension,
+ bool is_content_script);
} // namespace custom_bindings_util

Powered by Google App Engine
@@ -33,10 +33,12 @@ std::vector<v8::Extension*> GetAll(ExtensionDispatcher* extension_dispatcher);
std::string GetAPIName(const std::string& v8_extension_name);
// Returns whether the custom binding for an API should be allowed to run for
-// |extension|. This is based on whether the extension has any permission
-// (required or optional) for that API.
+// |extension|. This is based on whether the extension has any permission
+// (required or optional) for that API, and whether the injection is intended
+// to be for a content script (as opposed to a normal extension page).
bool AllowAPIInjection(const std::string& api_name,
This is Rietveld 408576698